@@ -6,7 +6,7 @@ torch_dtype <- R6::R6Class(
       self$ptr <- ptr
     },
     print = function() {
-      cat("torch_", self$.type(), sep = "")
+      cat("torch_", self$.type(), "\n", sep = "")
     },
     .type = function() {
       cpp_dtype_to_string(self$ptr)
