@@ -9,6 +9,18 @@
   candidates
 }
 
+#' @importFrom utils .DollarNames
+#' @export
+.DollarNames.nn_module <- function(x, pattern = "") {
+  
+  pars <- names(x[[".__enclos_env__"]][["private"]][["parameters_"]])
+  bufs <- names(x[[".__enclos_env__"]][["private"]][["buffers_"]])
+  mods <- names(x[[".__enclos_env__"]][["private"]][["modules_"]])
+  candidates <- unique(c(pars, bufs, mods, names(x)))
+  candidates <- sub("(^[0-9]+.*)", replacement = "`\\1`", candidates)
+  candidates <- sort(candidates[grepl(pattern, candidates)])
+  candidates
+}
 
 help_formals_handler.torch_tensor <- function(topic, source, ...) {
   list(
