@@ -73,6 +73,9 @@
   if (!is_torch_tensor(e1))
     e1 <- torch_tensor(e1, device = e2$device)
   
+  if (!is_torch_tensor(e2))
+    e2 <- torch_tensor(e2, device = e1$device)
+  
   torch_ge(e1, e2)
 }
 
@@ -82,6 +85,9 @@
   if (!is_torch_tensor(e1))
     e1 <- torch_tensor(e1, device = e2$device)
   
+  if (!is_torch_tensor(e2))
+    e2 <- torch_tensor(e2, device = e1$device)
+  
   torch_gt(e1, e2)
 }
 
@@ -91,6 +97,9 @@
   if (!is_torch_tensor(e1))
     e1 <- torch_tensor(e1, device = e2$device)
   
+  if (!is_torch_tensor(e2))
+    e2 <- torch_tensor(e2, device = e1$device)
+  
   torch_le(e1, e2)
 }
 
@@ -100,6 +109,9 @@
   if (!is_torch_tensor(e1))
     e1 <- torch_tensor(e1, device = e2$device)
   
+  if (!is_torch_tensor(e2))
+    e2 <- torch_tensor(e2, device = e1$device)
+  
   torch_lt(e1, e2)
 }
 
@@ -109,6 +121,9 @@
   if (!is_torch_tensor(e1))
     e1 <- torch_tensor(e1, device = e2$device)
   
+  if (!is_torch_tensor(e2))
+    e2 <- torch_tensor(e2, device = e1$device)
+  
   torch_eq(e1, e2)
 }
 
@@ -127,6 +142,9 @@
   if (!is_torch_tensor(e1))
     e1 <- torch_tensor(e1, device = e2$device)
   
+  if (!is_torch_tensor(e2))
+    e2 <- torch_tensor(e2, device = e1$device)
+  
   torch_logical_and(e1, e2)
 }
 
@@ -136,6 +154,9 @@
   if (!is_torch_tensor(e1))
     e1 <- torch_tensor(e1, device = e2$device)
   
+  if (!is_torch_tensor(e2))
+    e2 <- torch_tensor(e2, device = e1$device)
+  
   torch_logical_or(e1, e2)
 }
 
