@@ -362,17 +362,22 @@ void cpp_autograd_context_set_arguments (Rcpp::XPtr<XPtrTorch> self, std::vector
   }
   
   lantern_AutogradContext_set_arguments(self->get(), names_, needs_grad_);
+  
+  lantern_vector_string_delete(names_);
+  lantern_vector_bool_delete(needs_grad_);
 }
 
 // [[Rcpp::export]]
 std::vector<std::string> cpp_autograd_context_get_argument_names (Rcpp::XPtr<XPtrTorch> self)
 {
-  auto v = lantern_AutogradContext_get_argument_names(self->get());
-  auto size = lantern_vector_string_size(v);
+  XPtrTorchvector_string v = lantern_AutogradContext_get_argument_names(self->get());
+  auto size = lantern_vector_string_size(v.get());
   std::vector<std::string> out;
   for (int i = 0; i < size; i++)
   {
-    out.push_back(std::string(lantern_vector_string_at(v, i)));
+    auto tmp = lantern_vector_string_at(v.get(), i);
+    out.push_back(std::string(tmp));
+    lantern_const_char_delete(tmp);
   }
   return out;
 }
@@ -380,12 +385,12 @@ std::vector<std::string> cpp_autograd_context_get_argument_names (Rcpp::XPtr<XPt
 // [[Rcpp::export]]
 std::vector<bool> cpp_autograd_context_get_argument_needs_grad (Rcpp::XPtr<XPtrTorch> self)
 {
-  auto v = lantern_AutogradContext_get_argument_needs_grad(self->get());
-  auto size = lantern_vector_bool_size(v);
+  XPtrTorchvector_bool v = lantern_AutogradContext_get_argument_needs_grad(self->get());
+  auto size = lantern_vector_bool_size(v.get());
   std::vector<bool> out;
   for (int i = 0; i < size; i++)
   {
-    out.push_back(lantern_vector_bool_at(v, i));
+    out.push_back(lantern_vector_bool_at(v.get(), i));
   }
   return out;
 }
@@ -393,24 +398,26 @@ std::vector<bool> cpp_autograd_context_get_argument_needs_grad (Rcpp::XPtr<XPtrT
 // [[Rcpp::export]]
 void cpp_autograd_context_set_saved_variables_names (Rcpp::XPtr<XPtrTorch> self, std::vector<std::string> names)
 {
-  auto names_ = lantern_vector_string_new();
+  XPtrTorchvector_string names_ = lantern_vector_string_new();
   for (int i = 0; i < names.size(); i ++)
   {
-    lantern_vector_string_push_back(names_, names.at(i).c_str());
+    lantern_vector_string_push_back(names_.get(), names.at(i).c_str());
   }
   
-  lantern_AutogradContext_set_saved_variables_names(self->get(), names_);
+  lantern_AutogradContext_set_saved_variables_names(self->get(), names_.get());
 }
 
 // [[Rcpp::export]]
 std::vector<std::string> cpp_autograd_context_get_saved_variables_names (Rcpp::XPtr<XPtrTorch> self)
 {
-  auto v = lantern_AutogradContext_get_saved_variables_names(self->get());
-  auto size = lantern_vector_string_size(v);
+  XPtrTorchvector_string v = lantern_AutogradContext_get_saved_variables_names(self->get());
+  auto size = lantern_vector_string_size(v.get());
   std::vector<std::string> out;
   for (int i = 0; i < size; i++)
   {
-    out.push_back(std::string(lantern_vector_string_at(v, i)));
+    auto tmp = lantern_vector_string_at(v.get(), i);
+    out.push_back(std::string(tmp));
+    lantern_const_char_delete(tmp);
   }
   return out;
 }
