@@ -3,9 +3,6 @@
 #include <string>
 #include <memory>
 
-void lantern_host_handler();
-#define LANTERN_HOST_HANDLER lantern_host_handler();
-
 #include "lantern/lantern.h"
 
 #include <Rcpp.h>
@@ -243,6 +240,13 @@ public:
   }
 };
 
+class XPtrTorchvector_bool : public XPtrTorch {
+public:
+  XPtrTorchvector_bool (void * x) : XPtrTorch {NULL} {
+    this->set(std::shared_ptr<void>(x, lantern_vector_bool_delete));
+  }
+};
+
 template<class T>
 class nullable {
 public:
