@@ -163,6 +163,14 @@ test_that("norm", {
     regexp = "not yet supported with named tensors"
   )
   
+  x <- torch_rand(2, 3)
+  expect_tensor(x$norm())
+  expect_tensor(x$norm(p = 2))
+  expect_tensor(x$norm(p = 2, dtype = torch_float64()))
+  expect_tensor_shape(torch_norm(x, dim = 1), 3)
+  expect_tensor_shape(torch_norm(x, dim = 2), 2)
+  expect_tensor_shape(torch_norm(x, dim = 2, dtype = torch_float64()), 2)
+  
 })
 
 test_that("hann_window", {
@@ -217,4 +225,10 @@ test_that("stft", {
   expect_tensor_shape(x, c(201, 27, 2))
   expect_equal_to_r(x[1,,], cbind(rep(400, 27), rep(0, 27)))
   expect_equal_to_r(x[51,,], cbind(rep(0, 27), rep(0, 27)))
+})
+
+test_that("torch_one_hot", {
+  expect_tensor_shape(torch_one_hot(torch_tensor(1L)), c(1,1))
+  expect_tensor_shape(torch_one_hot(torch_tensor(c(1L, 2L))), c(2,2))
+  expect_error(torch_one_hot(torch_tensor(0L)))
 })
\ No newline at end of file
